<?php
/**
 * ZanCms
 * ============================================================================
 * 版权所有 2020-2035 海南赞赞网络科技有限公司，并保留所有权利。
 * 网站地址: http://www.zancms.com
 * ----------------------------------------------------------------------------
 * 如果商业用途务必到官方购买正版授权, 以免引起不必要的法律纠纷.
 * ============================================================================
 * Author: 小虎哥 <1105415366@qq.com>
 * Date: 2018-4-3
 */

namespace app\admin\controller;

use think\Db;
use think\Page;

class Xiazai extends Base
{
    // 模型标识
    public $nid = 'xiazai';
    // 模型ID
    public $channeltype = '';

    public function _initialize()
    {
        parent::_initialize();
        $channeltype_list  = config('global.channeltype_list');
        $this->channeltype = $channeltype_list[$this->nid];
        empty($this->channeltype) && $this->channeltype = 10;
        $this->assign('nid', $this->nid);
        $this->assign('channeltype', $this->channeltype);

        // 当前时间戳
        $this->times = getTime();

        // 返回页面
        $paramTypeid = input('param.typeid/d', 0);
        $this->callback_url = url('Xiazai/index', ['lang' => $this->admin_lang, 'typeid' => $paramTypeid]);
        $this->assign('callback_url', $this->callback_url);

        $functionLogic = new \app\common\logic\FunctionLogic;
        $functionLogic->validate_authorfile(1);
    }

    // 列表
    public function index()
    {
        $param = input('param.');
        $param['channel'] = $this->channeltype;
        $result = model('Archives')->getArchivesList($param);
        // 查询下载列表数据
        $aidArr = !empty($result['list']) ? get_arr_column($result['list'], 'aid') : [];
        if (!empty($aidArr)) {
            $where = [
                'aid' => ['IN', $aidArr],
                'lang' => $this->admin_lang,
            ];
            $xiazaiFile = Db::name('xiazai_file')->where($where)->getAllWithIndex('aid');
            foreach ($result['list'] as $key => $value) {
                $result['list'][$key]['file'] = !empty($xiazaiFile[$value['aid']]) ? $xiazaiFile[$value['aid']] : [];
            }
        }
        $this->assign($result);
        return $this->fetch();
    }

    // 添加
    public function add()
    {
        $admin_info = session('admin_info');
        $this->assign('admin_info', $admin_info);
        $auth_role_info = $admin_info['auth_role_info'];
        $this->assign('auth_role_info', $auth_role_info);

        if (IS_AJAX_POST) {
            $post = input('post.');
            // 文档基础数据
            $insert = [
                'typeid'      => !empty($post['stypeid'][0]) ? intval($post['stypeid'][0]) : 0,
                'stypeid'     => !empty($post['stypeid']) ? implode(',', $post['stypeid']) : '',
                'channel'     => $this->channeltype,
                'title'       => trim($post['title']),
                'click'       => mt_rand(100, 1000),
                'author'      => !empty($admin_info['pen_name']) ? trim($admin_info['pen_name']) : '小编',
                'sort_order'  => 100,
                'admin_id'    => !empty($admin_info['admin_id']) ? intval($admin_info['admin_id']) : 0,
                'add_time'    => $this->times,
                'update_time' => $this->times,
            ];
            // 处理自定义路由
            $htmlfilename = implode('', explode(PHP_EOL, trim($post['title'])));
            $insert['htmlfilename'] = model('Archives')->customRouteHandle(0, preg_replace("/[^\x{4e00}-\x{9fa5}\w\-]+/u", "-", strtolower($htmlfilename)));
            if (preg_match('/^\d+$/', trim($insert['htmlfilename']))) $this->error('标题不允许纯数字');
            $aid = Db::name('archives')->insertGetId($insert);
            if (!empty($aid)) {
                // 对应语言表
                $insert['aid'] = intval($aid);
                unset($insert['typeid'], $insert['stypeid'], $insert['channel']);
                $list = Db::name('language')->where(['status' => 1])->column('mark');
                foreach ($list as $lang) {
                    Db::name('archives_' . $lang)->insert($insert);
                }

                // 文档文件数据
                $file = [
                    'aid'         => intval($aid),
                    'title'       => trim($post['title']),
                    'uhash'       => !empty($post['file']['uhash']) ? trim($post['file']['uhash']) : '',
                    'md5file'     => !empty($post['file']['md5file']) ? trim($post['file']['md5file']) : '',
                    'file_url'    => !empty($post['file']['file_url']) ? trim($post['file']['file_url']) : '',
                    'file_ext'    => !empty($post['file']['file_ext']) ? trim($post['file']['file_ext']) : '',
                    'file_name'   => !empty($post['file']['file_name']) ? trim($post['file']['file_name']) : '',
                    'file_mime'   => !empty($post['file']['file_mime']) ? trim($post['file']['file_mime']) : '',
                    'file_size'   => !empty($post['file']['file_size']) ? intval($post['file']['file_size']) : 0,
                    'sort_order'  => 100,
                    'lang'        => $this->showLang,
                    'add_time'    => $this->times,
                    'update_time' => $this->times,
                ];
                Db::name('xiazai_file')->insertAll(model('Language')->getMultiLanguageInsertAll($file));

                // 记录日志
                adminLog('新增下载：' . trim($post['title']));
                // 结束返回
                $this->success("新增成功");
            }
            $this->error("操作失败");
        }

        $id = input('id/d', 0);
        $stypeid = Db::name('archives')->where(['aid' => $id])->getField('stypeid');
        $assign_data['stypeid'] = $stypeid;

        // 允许发布文档列表的栏目，文档所在模型以栏目所在模型为主，兼容切换模型之后的数据编辑
        $arctype_list = allow_release_arctype(0, array($this->channeltype), false);
        $assign_data['arctype_list'] = $arctype_list;

        // 文件格式
        $file_type = tpCache('basic.file_type');
        if (empty($file_type)) $file_type = 'zip|gz|rar|iso|doc|xls|ppt|wps|docx|xlsx|pptx|pdf|xlsx';
        $assign_data['file_type'] = $file_type;

        $this->assign($assign_data);
        return $this->fetch();
    }
    
    // 编辑
    public function edit()
    {
        $admin_info = session('admin_info');
        $this->assign('admin_info', $admin_info);
        $auth_role_info = $admin_info['auth_role_info'];
        $this->assign('auth_role_info', $auth_role_info);

        if (IS_AJAX_POST) {
            $post = input('post.');
            // 执行条件
            $where = [
                'aid' => intval($post['aid'])
            ];
            // 文档基础数据
            $update = [
                'typeid'      => !empty($post['stypeid'][0]) ? intval($post['stypeid'][0]) : 0,
                'stypeid'     => !empty($post['stypeid']) ? implode(',', $post['stypeid']) : '',
                'update_time' => $this->times,
            ];
            $resultID = Db::name('archives')->where($where)->update($update);
            if (!empty($resultID)) {
                // 文档文件数据
                $saveFile = [];
                foreach ($post['file']['file_id'] as $key => $value) {
                    $saveFile[] = [
                        'file_id'     => intval($value),
                        'title'       => !empty($post['file']['title'][$key]) ? trim($post['file']['title'][$key]) : '',
                        'uhash'       => !empty($post['file']['uhash'][$key]) ? trim($post['file']['uhash'][$key]) : '',
                        'md5file'     => !empty($post['file']['md5file'][$key]) ? trim($post['file']['md5file'][$key]) : '',
                        'file_url'    => !empty($post['file']['file_url'][$key]) ? trim($post['file']['file_url'][$key]) : '',
                        'file_ext'    => !empty($post['file']['file_ext'][$key]) ? trim($post['file']['file_ext'][$key]) : '',
                        'file_name'   => !empty($post['file']['file_name'][$key]) ? trim($post['file']['file_name'][$key]) : '',
                        'file_mime'   => !empty($post['file']['file_mime'][$key]) ? trim($post['file']['file_mime'][$key]) : '',
                        'file_size'   => !empty($post['file']['file_size'][$key]) ? intval($post['file']['file_size'][$key]) : 0,
                        'update_time' => $this->times,
                    ];
                }
                if (!empty($saveFile)) model('XiazaiFile')->saveAll($saveFile);
                // 结束返回
                $this->success("编辑成功");
            }
            $this->error("操作失败");
        }

        $assign_data = [];
        $id = input('id/d', 0);
        $showlang = input('showlang/s', '');
        $info = model('Archives')->getArchivesDetails($id);
        if (empty($info)) $this->error('数据不存在，请联系管理员！');
        $assign_data['field'] = $info;
        $where = [
            'aid' => ['IN', $info['aid']],
        ];
        $xiazaiFile = Db::name('xiazai_file')->where($where)->getAllWithIndex('lang');
        foreach ($xiazaiFile as $key => $value) {
            $unit = 'B';
            if (intval($value['file_size']) > 1024) {
                $unit = 'KB';
                $value['file_size'] = intval(intval($value['file_size']) / 1024);
            }
            if (intval($value['file_size']) > 1024) {
                $unit = 'M';
                $value['file_size'] = sprintf("%.2f", intval($value['file_size']) / 1024);
            }
            $xiazaiFile[$key]['file_size'] = $value['file_size'] . $unit;
        }
        $assign_data['xiazaiFile'] = $xiazaiFile;

        // 允许发布文档列表的栏目，文档所在模型以栏目所在模型为主，兼容切换模型之后的数据编辑
        $arctype_list = allow_release_arctype(0, array($this->channeltype), false);
        $assign_data['arctype_list'] = $arctype_list;
        
        // 豆包翻译API配置
        $doubao = tpSetting('doubao', [], $this->show_lang);
        $this->assign('doubao', $doubao);

        // 文件格式
        $file_type = tpCache('basic.file_type');
        if (empty($file_type)) $file_type = 'zip|gz|rar|iso|doc|xls|ppt|wps|docx|xlsx|pptx|pdf|xlsx';
        $assign_data['file_type'] = $file_type;
        
        $this->assign($assign_data);
        return $this->fetch();
    }

    //删除
    public function del()
    {
        if (IS_AJAX_POST) {
            $del_id = input('del_id/a');
            if (empty($del_id)) $this->error('请选择需要删除的文档');
            $where = [
                'aid' => ['IN', $del_id]
            ];
            // 删除文档数据
            $result = Db::name('archives')->where($where)->cache(true, EYOUCMS_CACHE_TIME, 'archives')->delete(true);
            if (!empty($result)) {
                // 删除下载文件数据
                Db::name('xiazai_file')->where($where)->delete(true);

                // 删除对应语言数据
                $list = Db::name('language')->where(['status' => 1])->column('mark');
                foreach ($list as $lang) {
                    @Db::name('archives_' . $lang)->where($where)->delete(true);
                }

                // 返回成功
                $this->success('删除成功');
            }
        }
        $this->error('操作失败');
    }
}